==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.DeleteOptions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile's network configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineScaleSetNetworkConfigurationArgs(
    public val deleteOption: Output<Either<String, DeleteOptions>>? = null,
    public val disableTcpStateTracking: Output<Boolean>? = null,
    public val dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null,
    public val enableAcceleratedNetworking: Output<Boolean>? = null,
    public val enableFpga: Output<Boolean>? = null,
    public val enableIPForwarding: Output<Boolean>? = null,
    public val ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>,
    public val name: Output<String>,
    public val networkSecurityGroup: Output<SubResourceArgs>? = null,
    public val primary: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder()
            .deleteOption(
                deleteOption?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .disableTcpStateTracking(disableTcpStateTracking?.applyValue({ args0 -> args0 }))
            .dnsSettings(dnsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enableAcceleratedNetworking(enableAcceleratedNetworking?.applyValue({ args0 -> args0 }))
            .enableFpga(enableFpga?.applyValue({ args0 -> args0 }))
            .enableIPForwarding(enableIPForwarding?.applyValue({ args0 -> args0 }))
            .ipConfigurations(
                ipConfigurations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .primary(primary?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkConfigurationArgsBuilder internal constructor() {
    private var deleteOption: Output<Either<String, DeleteOptions>>? = null

    private var disableTcpStateTracking: Output<Boolean>? = null

    private var dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null

    private var enableAcceleratedNetworking: Output<Boolean>? = null

    private var enableFpga: Output<Boolean>? = null

    private var enableIPForwarding: Output<Boolean>? = null

    private var ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<SubResourceArgs>? = null

    private var primary: Output<Boolean>? = null

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("gfvfhsumddocvyvn")
    public suspend fun deleteOption(`value`: Output<Either<String, DeleteOptions>>) {
        this.deleteOption = value
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("yhatovvscywomvna")
    public suspend fun disableTcpStateTracking(`value`: Output<Boolean>) {
        this.disableTcpStateTracking = value
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("skvesoovkckidokx")
    public suspend
    fun dnsSettings(`value`: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>) {
        this.dnsSettings = value
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("ljwsbcuwbnffvjbl")
    public suspend fun enableAcceleratedNetworking(`value`: Output<Boolean>) {
        this.enableAcceleratedNetworking = value
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("bgfklueksnwboxsw")
    public suspend fun enableFpga(`value`: Output<Boolean>) {
        this.enableFpga = value
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("qeohdvvlwawbgsgv")
    public suspend fun enableIPForwarding(`value`: Output<Boolean>) {
        this.enableIPForwarding = value
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("wqxjjfcgpelxaclo")
    public suspend
    fun ipConfigurations(`value`: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = value
    }

    @JvmName("olvdrrtmhsrwplsr")
    public suspend fun ipConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetIPConfigurationArgs>,
    ) {
        this.ipConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("mfwmlbgkuuccvbeg")
    public suspend
    fun ipConfigurations(values: List<Output<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = Output.all(values)
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("tptotexbksohsuoq")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The network security group.
     */
    @JvmName("noehejbhgunytnjh")
    public suspend fun networkSecurityGroup(`value`: Output<SubResourceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("uxdqwrovrijchhgb")
    public suspend fun primary(`value`: Output<Boolean>) {
        this.primary = value
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("emlfurdiejrjrogq")
    public suspend fun deleteOption(`value`: Either<String, DeleteOptions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("kxxglxxnypgknoeq")
    public fun deleteOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("jydsxxaedwblixjf")
    public fun deleteOption(`value`: DeleteOptions) {
        val toBeMapped = Either.ofRight<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("ebhcvtjjgfooxvea")
    public suspend fun disableTcpStateTracking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableTcpStateTracking = mapped
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("yaxodkjkouxuhcqx")
    public suspend
    fun dnsSettings(`value`: VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsSettings = mapped
    }

    /**
     * @param argument The dns settings to be applied on the network interfaces.
     */
    @JvmName("dvhknfivindebmmu")
    public suspend
    fun dnsSettings(argument: suspend VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dnsSettings = mapped
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("ihevlkhscbktxqbv")
    public suspend fun enableAcceleratedNetworking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAcceleratedNetworking = mapped
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("peogslfbksmbteao")
    public suspend fun enableFpga(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableFpga = mapped
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("wjhmgywjfyyefjlk")
    public suspend fun enableIPForwarding(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableIPForwarding = mapped
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("bqbrjfwejcyaawed")
    public suspend fun ipConfigurations(`value`: List<VirtualMachineScaleSetIPConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("uftblxnvetgxdvfa")
    public suspend
    fun ipConfigurations(argument: List<suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("turcicbfrmtrqxrq")
    public suspend fun ipConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("bbbqtcfiidmntxhy")
    public suspend
    fun ipConfigurations(argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("mnxogskkdbqehyla")
    public suspend fun ipConfigurations(vararg values: VirtualMachineScaleSetIPConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("dcxqgeqbxyndoafm")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The network security group.
     */
    @JvmName("agolcfjiuklahvou")
    public suspend fun networkSecurityGroup(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument The network security group.
     */
    @JvmName("yfwpihqdoghltacw")
    public suspend fun networkSecurityGroup(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("ojswvcyimrdjciyd")
    public suspend fun primary(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primary = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkConfigurationArgs =
        VirtualMachineScaleSetNetworkConfigurationArgs(
            deleteOption = deleteOption,
            disableTcpStateTracking = disableTcpStateTracking,
            dnsSettings = dnsSettings,
            enableAcceleratedNetworking = enableAcceleratedNetworking,
            enableFpga = enableFpga,
            enableIPForwarding = enableIPForwarding,
            ipConfigurations = ipConfigurations ?: throw PulumiNullFieldException("ipConfigurations"),
            name = name ?: throw PulumiNullFieldException("name"),
            networkSecurityGroup = networkSecurityGroup,
            primary = primary,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VirtualMachineScaleSetNetworkConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder
import com.pulumi.azurenative.compute.kotlin.enums.DeleteOptions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a virtual machine scale set network profile's network configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineScaleSetNetworkConfigurationArgs(
    public val deleteOption: Output<Either<String, DeleteOptions>>? = null,
    public val disableTcpStateTracking: Output<Boolean>? = null,
    public val dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null,
    public val enableAcceleratedNetworking: Output<Boolean>? = null,
    public val enableFpga: Output<Boolean>? = null,
    public val enableIPForwarding: Output<Boolean>? = null,
    public val ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>,
    public val name: Output<String>,
    public val networkSecurityGroup: Output<SubResourceArgs>? = null,
    public val primary: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs> {
    override fun toJava():
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs =
        com.pulumi.azurenative.compute.inputs.VirtualMachineScaleSetNetworkConfigurationArgs.builder()
            .deleteOption(
                deleteOption?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .disableTcpStateTracking(disableTcpStateTracking?.applyValue({ args0 -> args0 }))
            .dnsSettings(dnsSettings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .enableAcceleratedNetworking(enableAcceleratedNetworking?.applyValue({ args0 -> args0 }))
            .enableFpga(enableFpga?.applyValue({ args0 -> args0 }))
            .enableIPForwarding(enableIPForwarding?.applyValue({ args0 -> args0 }))
            .ipConfigurations(
                ipConfigurations.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .name(name.applyValue({ args0 -> args0 }))
            .networkSecurityGroup(
                networkSecurityGroup?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .primary(primary?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualMachineScaleSetNetworkConfigurationArgs].
 */
@PulumiTagMarker
public class VirtualMachineScaleSetNetworkConfigurationArgsBuilder internal constructor() {
    private var deleteOption: Output<Either<String, DeleteOptions>>? = null

    private var disableTcpStateTracking: Output<Boolean>? = null

    private var dnsSettings: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>? = null

    private var enableAcceleratedNetworking: Output<Boolean>? = null

    private var enableFpga: Output<Boolean>? = null

    private var enableIPForwarding: Output<Boolean>? = null

    private var ipConfigurations: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>? = null

    private var name: Output<String>? = null

    private var networkSecurityGroup: Output<SubResourceArgs>? = null

    private var primary: Output<Boolean>? = null

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("hdtrtuaaggfpgdnb")
    public suspend fun deleteOption(`value`: Output<Either<String, DeleteOptions>>) {
        this.deleteOption = value
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("awceafawoajicjlw")
    public suspend fun disableTcpStateTracking(`value`: Output<Boolean>) {
        this.disableTcpStateTracking = value
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("pyvyquvnnftjteva")
    public suspend
    fun dnsSettings(`value`: Output<VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs>) {
        this.dnsSettings = value
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("bqsftswrtnrpipfi")
    public suspend fun enableAcceleratedNetworking(`value`: Output<Boolean>) {
        this.enableAcceleratedNetworking = value
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("yqjiyvghmifqcadx")
    public suspend fun enableFpga(`value`: Output<Boolean>) {
        this.enableFpga = value
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("hegcrcgmprktpgom")
    public suspend fun enableIPForwarding(`value`: Output<Boolean>) {
        this.enableIPForwarding = value
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("pvswkbeckhuebchh")
    public suspend
    fun ipConfigurations(`value`: Output<List<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = value
    }

    @JvmName("ofrvvvajjadyqudh")
    public suspend fun ipConfigurations(
        vararg
        values: Output<VirtualMachineScaleSetIPConfigurationArgs>,
    ) {
        this.ipConfigurations = Output.all(values.asList())
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("pixkjkvywfnvwlue")
    public suspend
    fun ipConfigurations(values: List<Output<VirtualMachineScaleSetIPConfigurationArgs>>) {
        this.ipConfigurations = Output.all(values)
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("nerafmnlxscctsaa")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The network security group.
     */
    @JvmName("qscxiscxuphramgo")
    public suspend fun networkSecurityGroup(`value`: Output<SubResourceArgs>) {
        this.networkSecurityGroup = value
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("yxsxyfojftkqfcla")
    public suspend fun primary(`value`: Output<Boolean>) {
        this.primary = value
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("iexdcwhjqvoliilw")
    public suspend fun deleteOption(`value`: Either<String, DeleteOptions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("ppmclxpqiapimivd")
    public fun deleteOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specify what happens to the network interface when the VM is deleted
     */
    @JvmName("olhyjjbkmeiirxob")
    public fun deleteOption(`value`: DeleteOptions) {
        val toBeMapped = Either.ofRight<String, DeleteOptions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.deleteOption = mapped
    }

    /**
     * @param value Specifies whether the network interface is disabled for tcp state tracking.
     */
    @JvmName("eroshkgubooddhsp")
    public suspend fun disableTcpStateTracking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.disableTcpStateTracking = mapped
    }

    /**
     * @param value The dns settings to be applied on the network interfaces.
     */
    @JvmName("rletntqgyrfnypqr")
    public suspend
    fun dnsSettings(`value`: VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsSettings = mapped
    }

    /**
     * @param argument The dns settings to be applied on the network interfaces.
     */
    @JvmName("cekekmqxjimbdlar")
    public suspend
    fun dnsSettings(argument: suspend VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder.() -> Unit) {
        val toBeMapped =
            VirtualMachineScaleSetNetworkConfigurationDnsSettingsArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.dnsSettings = mapped
    }

    /**
     * @param value Specifies whether the network interface is accelerated networking-enabled.
     */
    @JvmName("toxkhoryerjpeicd")
    public suspend fun enableAcceleratedNetworking(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableAcceleratedNetworking = mapped
    }

    /**
     * @param value Specifies whether the network interface is FPGA networking-enabled.
     */
    @JvmName("fhrcnomwpcfkuqdp")
    public suspend fun enableFpga(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableFpga = mapped
    }

    /**
     * @param value Whether IP forwarding enabled on this NIC.
     */
    @JvmName("dtedqifaiqlknnbs")
    public suspend fun enableIPForwarding(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enableIPForwarding = mapped
    }

    /**
     * @param value Specifies the IP configurations of the network interface.
     */
    @JvmName("wklujjwnsatintrb")
    public suspend fun ipConfigurations(`value`: List<VirtualMachineScaleSetIPConfigurationArgs>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("kwtkjsrfdcnimsgd")
    public suspend
    fun ipConfigurations(argument: List<suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("iwharqspyxonpkex")
    public suspend fun ipConfigurations(
        vararg
        argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param argument Specifies the IP configurations of the network interface.
     */
    @JvmName("evydubrcejtiigis")
    public suspend
    fun ipConfigurations(argument: suspend VirtualMachineScaleSetIPConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualMachineScaleSetIPConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.ipConfigurations = mapped
    }

    /**
     * @param values Specifies the IP configurations of the network interface.
     */
    @JvmName("iiuflqcvqpsvymid")
    public suspend fun ipConfigurations(vararg values: VirtualMachineScaleSetIPConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipConfigurations = mapped
    }

    /**
     * @param value The network configuration name.
     */
    @JvmName("hhhmhgdqcylxtold")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The network security group.
     */
    @JvmName("ybqmusqdownjklht")
    public suspend fun networkSecurityGroup(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkSecurityGroup = mapped
    }

    /**
     * @param argument The network security group.
     */
    @JvmName("pogtdrsaubiheiwi")
    public suspend fun networkSecurityGroup(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkSecurityGroup = mapped
    }

    /**
     * @param value Specifies the primary network interface in case the virtual machine has more than 1 network interface.
     */
    @JvmName("rjhcxxxsxshbldgm")
    public suspend fun primary(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primary = mapped
    }

    internal fun build(): VirtualMachineScaleSetNetworkConfigurationArgs =
        VirtualMachineScaleSetNetworkConfigurationArgs(
            deleteOption = deleteOption,
            disableTcpStateTracking = disableTcpStateTracking,
            dnsSettings = dnsSettings,
            enableAcceleratedNetworking = enableAcceleratedNetworking,
            enableFpga = enableFpga,
            enableIPForwarding = enableIPForwarding,
            ipConfigurations = ipConfigurations ?: throw PulumiNullFieldException("ipConfigurations"),
            name = name ?: throw PulumiNullFieldException("name"),
            networkSecurityGroup = networkSecurityGroup,
            primary = primary,
        )
}
